"""
Python example for accessing IMatch or IMatch WebServices
See https://www.photools.com/developer-center/ for more info.
"""

import os         # For Windows stuff
import json       # json library
import requests   # See: http://docs.python-requests.org/en/master/

HOST_URL = 'http://127.0.0.1:50519'     # Where to reach IMWS or the embedded IMWS in IMatch
REQUEST_TIMEOUT = 10                    # Request timeout in seconds

auth_token = ''                         # This stores the IMWS authentication token after authenticate() has been called


# -----------------------------------------------------------------------------
#
def authenticate():
    """ Authenticate against IMWS and set the auth_token variable
        to the returned authentication token. We need this for all other endpoints. """

    global auth_token

    try:
        req = requests.post(HOST_URL + '/v1/authenticate', params={
            'id': os.getlogin(),
            'password': '',
            'appid': ''},
            timeout=REQUEST_TIMEOUT)

        # Conert the JSON responrce
        response = json.loads(req.text)

        # If we're OK, store the auth_token in the global variable
        if req.status_code == requests.codes.ok:
            auth_token = response["auth_token"]
        else:
            # Raise the exception matching the HTTP status code
            req.raise_for_status()

        return

    except requests.exceptions.RequestException as re:
        print(re)
        print(response)

    except Exception as ex:
        print(ex)


# -----------------------------------------------------------------------------
#
def list_file_names():
    """ Print the id and name of all selected files in the active file window. """

    try:
        req = requests.get(HOST_URL + '/v1/files', params={
           'auth_token': auth_token,
           'idlist': '@imatch.filewindow.active.selection',
           'fields': 'id,filename'
        }, timeout=REQUEST_TIMEOUT)

        response = json.loads(req.text)

        if req.status_code == requests.codes.ok:

            for f in response['files']:
                print(f['id'],' ',f['fileName'])

        else:
            req.raise_for_status()

        return

    except requests.exceptions.RequestException as re:
        print(re)
        print(response)

    except Exception as ex:
        print(ex)

# First authenticate
authenticate()

# Now list the files selected in the active file window
list_file_names()
